@@ -4,7 +4,7 @@ use v5.10;
 use strict;
 use warnings;
 
-our $VERSION = "2.01";
+our $VERSION = "2.02";
 
 use strict;
 use warnings;
@@ -34,7 +34,7 @@ sub sprintf {
     $result;
 }
 
-sub printf ($$@) {
+sub printf {
     my $fh = ref $_[0] eq 'GLOB' ? shift : select;
     $fh->printf(&sprintf(@_));
 }
@@ -47,7 +47,7 @@ sub _sub_uniqstr {
 	my $len = Text::VisualWidth::PP::width(shift)
 	    or croak "Unexpected input.";
 	$len == 1 and return "\006";
-	$n > 25 and $n = 25;
+	$n > 24 and $n = 24;
 	my $s = pack("CC", $n / 5 + 1, $n % 5 + 1) . ("_" x ($len - 2));
 	$n++;
 	$s;
@@ -116,6 +116,8 @@ number or arguments exceeds 25, they are encoded by same code.
 
 L<Text::VisualWidth::PP>
 
+L<https://github.com/kaz-utashiro/Text-VisualPrintf>
+
 =head1 AUTHOR
 
 Kaz Utashiro
